@@ -5,8 +5,8 @@ import (
 	"testing"
 
 	"github.com/derailed/k9s/internal/model"
+	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
-	"github.com/gdamore/tcell/v2"
 	"github.com/rs/zerolog"
 	"github.com/stretchr/testify/assert"
 )
