@@ -7,13 +7,14 @@ import (
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tview"
 	"github.com/stretchr/testify/assert"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
 func TestDeleteDialog(t *testing.T) {
 	p := ui.NewPages()
 
-	okFunc := func(c, f bool) {
-		assert.True(t, c)
+	okFunc := func(p *metav1.DeletionPropagation, f bool) {
+		assert.Equal(t, propagationOptions[defaultPropagationIdx], p)
 		assert.True(t, f)
 	}
 	caFunc := func() {
