@@ -2,11 +2,9 @@ package ui
 
 import (
 	"strings"
-	"time"
 	"unicode"
 
 	"github.com/derailed/k9s/internal/render"
-	"k8s.io/apimachinery/pkg/util/duration"
 )
 
 // MaxyPad tracks uniform column padding.
@@ -55,12 +53,3 @@ func Pad(s string, width int) string {
 	}
 	return s + strings.Repeat(" ", width-len(s))
 }
-
-func toAgeHuman(s string) string {
-	t, err := time.Parse(time.RFC3339Nano, s)
-	if err != nil {
-		return render.NAValue
-	}
-
-	return duration.HumanDuration(time.Since(t))
-}
